==> cegui-mk2_0.4.1.orig.tar.gz: cegui_mk2/src/elements/CEGUIScrollbarProperties.cpp <==
/************************************************************************
	filename: 	CEGUIScrollbarProperties.cpp
	created:	10/7/2004
	author:		Paul D Turner
	
	purpose:	Implements properties for the scroll bar.
*************************************************************************/
/*************************************************************************
    Crazy Eddie's GUI System (http://www.cegui.org.uk)
    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*************************************************************************/
#include "elements/CEGUIScrollbarProperties.h"
#include "elements/CEGUIScrollbar.h"
#include "CEGUIPropertyHelper.h"


// Start of CEGUI namespace section
namespace CEGUI
{

// Start of ScrollbarProperties namespace section
namespace ScrollbarProperties
{
String	DocumentSize::get(const PropertyReceiver* receiver) const
{
	return PropertyHelper::floatToString(static_cast<const Scrollbar*>(receiver)->getDocumentSize());
}


void	DocumentSize::set(PropertyReceiver* receiver, const String& value)
{
	static_cast<Scrollbar*>(receiver)->setDocumentSize(PropertyHelper::stringToFloat(value));
}


String	PageSize::get(const PropertyReceiver* receiver) const
{
	return PropertyHelper::floatToString(static_cast<const Scrollbar*>(receiver)->getPageSize());
}


void	PageSize::set(PropertyReceiver* receiver, const String& value)
{
	static_cast<Scrollbar*>(receiver)->setPageSize(PropertyHelper::stringToFloat(value));
}


String	StepSize::get(const PropertyReceiver* receiver) const
{
	return PropertyHelper::floatToString(static_cast<const Scrollbar*>(receiver)->getStepSize());
}


void	StepSize::set(PropertyReceiver* receiver, const String& value)
{
	static_cast<Scrollbar*>(receiver)->setStepSize(PropertyHelper::stringToFloat(value));
}


String	OverlapSize::get(const PropertyReceiver* receiver) const
{
	return PropertyHelper::floatToString(static_cast<const Scrollbar*>(receiver)->getOverlapSize());
}


void	OverlapSize::set(PropertyReceiver* receiver, const String& value)
{
	static_cast<Scrollbar*>(receiver)->setOverlapSize(PropertyHelper::stringToFloat(value));
}


String	ScrollPosition::get(const PropertyReceiver* receiver) const
{
	return PropertyHelper::floatToString(static_cast<const Scrollbar*>(receiver)->getScrollPosition());
}


void	ScrollPosition::set(PropertyReceiver* receiver, const String& value)
{
	static_cast<Scrollbar*>(receiver)->setScrollPosition(PropertyHelper::stringToFloat(value));
}

} // End of  ScrollbarProperties namespace section

} // End of  CEGUI namespace section

==> cegui-mk2_0.5.0.orig.tar.gz: cegui_mk2/src/elements/CEGUIScrollbarProperties.cpp <==
/***********************************************************************
	filename: 	CEGUIScrollbarProperties.cpp
	created:	10/7/2004
	author:		Paul D Turner
	
	purpose:	Implements properties for the scroll bar.
*************************************************************************/
/***************************************************************************
 *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
 *
 *   Permission is hereby granted, free of charge, to any person obtaining
 *   a copy of this software and associated documentation files (the
 *   "Software"), to deal in the Software without restriction, including
 *   without limitation the rights to use, copy, modify, merge, publish,
 *   distribute, sublicense, and/or sell copies of the Software, and to
 *   permit persons to whom the Software is furnished to do so, subject to
 *   the following conditions:
 *
 *   The above copyright notice and this permission notice shall be
 *   included in all copies or substantial portions of the Software.
 *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 *   OTHER DEALINGS IN THE SOFTWARE.
 ***************************************************************************/
#include "elements/CEGUIScrollbarProperties.h"
#include "elements/CEGUIScrollbar.h"
#include "CEGUIPropertyHelper.h"


// Start of CEGUI namespace section
namespace CEGUI
{

// Start of ScrollbarProperties namespace section
namespace ScrollbarProperties
{
String	DocumentSize::get(const PropertyReceiver* receiver) const
{
	return PropertyHelper::floatToString(static_cast<const Scrollbar*>(receiver)->getDocumentSize());
}


void	DocumentSize::set(PropertyReceiver* receiver, const String& value)
{
	static_cast<Scrollbar*>(receiver)->setDocumentSize(PropertyHelper::stringToFloat(value));
}


String	PageSize::get(const PropertyReceiver* receiver) const
{
	return PropertyHelper::floatToString(static_cast<const Scrollbar*>(receiver)->getPageSize());
}


void	PageSize::set(PropertyReceiver* receiver, const String& value)
{
	static_cast<Scrollbar*>(receiver)->setPageSize(PropertyHelper::stringToFloat(value));
}


String	StepSize::get(const PropertyReceiver* receiver) const
{
	return PropertyHelper::floatToString(static_cast<const Scrollbar*>(receiver)->getStepSize());
}


void	StepSize::set(PropertyReceiver* receiver, const String& value)
{
	static_cast<Scrollbar*>(receiver)->setStepSize(PropertyHelper::stringToFloat(value));
}


String	OverlapSize::get(const PropertyReceiver* receiver) const
{
	return PropertyHelper::floatToString(static_cast<const Scrollbar*>(receiver)->getOverlapSize());
}


void	OverlapSize::set(PropertyReceiver* receiver, const String& value)
{
	static_cast<Scrollbar*>(receiver)->setOverlapSize(PropertyHelper::stringToFloat(value));
}


String	ScrollPosition::get(const PropertyReceiver* receiver) const
{
	return PropertyHelper::floatToString(static_cast<const Scrollbar*>(receiver)->getScrollPosition());
}


void	ScrollPosition::set(PropertyReceiver* receiver, const String& value)
{
	static_cast<Scrollbar*>(receiver)->setScrollPosition(PropertyHelper::stringToFloat(value));
}

} // End of  ScrollbarProperties namespace section

} // End of  CEGUI namespace section
